@@ -1,9 +1,9 @@
 from .population import BasePopulation
 from .mortality import Mortality
 from .observer import Observer
-from .disease import DiseaseModel, DiseaseState, DiseaseTransition, SIS_DiseaseModel
-from .risk import Risk, DirectEffect
-from .intervention import MagicWandIntervention
+from .disease import DiseaseModel, DiseaseState, DiseaseTransition, SISDiseaseModel
+from .risk import Risk, RiskEffect
+from .intervention import TreatmentIntervention
 
 
 def get_model_specification_path():
